import io
import gaussian
import shape
import lut
import numpy
from PIL import Image
import cv2

def apply(image, weight = 6, output_scale = 800):
    _, buffer = cv2.imencode('.png', image)
    io_buf = io.BytesIO(buffer)

    pil_image = Image.open(io_buf).convert('RGBA')

    width, height = pil_image.size
    
    image = numpy.array(image)
    
    hr_image = shape.resize(image, (width, height))

    image_smothing = gaussian.apply(hr_image, weight)

    lut_result = lut.apply(image_smothing)

    result = shape.resize(lut_result, (width, height), output_scale)

    return result



import cv2
import numpy

def apply(image):
    lut_in = [0, 255, 80]
    lut_out = [0, 0, 255]

    model = numpy.arange(0, 256)

    lut_8u = numpy.interp(model, lut_in, lut_out).astype(numpy.uint8)
    result = cv2.LUT(image, lut_8u)

    return result



import cv2

def resize(image, original_size, width_scale = 1000):
    print(original_size)
    width, height = original_size

    ratio = width / height

    additional_width = width_scale - width

    additional_height = additional_width // ratio

    print(type(image))

    hr_image = cv2.resize(image, (int(width + additional_width), int(height + additional_height)))

    return hr_image


import cv2

def apply(image, weight = 5):
    result = image
    ksizes = [1, 1]
    max_applies = (weight // 2) + 1

    if (weight < 1 or weight > 10):
        raise Exception("Weight must be between 1 and 10. The received value was {}".format(weight))

    ksizes[0] = ksizes[1] = weight * 2

    if (ksizes[0] % 2 == 0):
        ksizes[0] = ksizes[1] = ksizes[1] - 1

    for _ in range(max_applies):
        result = cv2.GaussianBlur(result, ksizes, cv2.BORDER_DEFAULT)

    return result
